(partition-query query cmd-argnum-map)Given a query sequence and a command argnum map (each keyword in map mapped to how many arguments that item expects), this function returns a sequence of sequences; each sub-sequence is just a single command, command keyword followed by args.
Given a query sequence and a command argnum map (each keyword in map mapped to how many arguments that item expects), this function returns a sequence of sequences; each sub-sequence is just a single command, command keyword followed by args.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |